==> jc-1.4.0.tar.gz: scm/scmsetCatchtable.h <==
// class scm.scmsetCatchtable

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure
// @dep_class 4c297c365d1f0c22 scm_scmsetCatchtable

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_scmsetCatchtable_H_
#define _JC_scm_scmsetCatchtable_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_scmsetCatchtable$sub_refs	_jc_scm_scmsetCatchtable$sub_refs;
typedef struct _jc_scm_scmsetCatchtable$sub_nonrefs	_jc_scm_scmsetCatchtable$sub_nonrefs;
typedef struct _jc_scm_scmsetCatchtable$refs	_jc_scm_scmsetCatchtable$refs;
typedef struct _jc_scm_scmsetCatchtable$nonrefs	_jc_scm_scmsetCatchtable$nonrefs;
typedef struct _jc_scm_scmsetCatchtable$object	_jc_scm_scmsetCatchtable$object;

typedef const struct _jc_scm_scmsetCatchtable$vmethods	_jc_scm_scmsetCatchtable$vmethods;
typedef const struct _jc_scm_scmsetCatchtable$vtable	_jc_scm_scmsetCatchtable$vtable;
typedef const struct _jc_scm_scmsetCatchtable$vtype	_jc_scm_scmsetCatchtable$vtype;

// Constructors
extern void _jc_scm_scmsetCatchtable$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_scmsetCatchtable$object *);

// Virtual methods
extern struct _jc_object *_jc_scm_scmsetCatchtable$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_scmsetCatchtable$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
extern struct _jc_java_lang_String$object *_jc_scm_scmsetCatchtable$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_scmsetCatchtable$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_scmsetCatchtable$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_scmsetCatchtable$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_scmsetCatchtable$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_scmsetCatchtable$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_scmsetCatchtable$object *);
};

// Vtable
struct _jc_scm_scmsetCatchtable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_scmsetCatchtable$vmethods	scm_scmsetCatchtable;
};

// Vtype
struct _jc_scm_scmsetCatchtable$vtype {
	_jc_type			type;
	_jc_scm_scmsetCatchtable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmsetCatchtable$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmsetCatchtable$refs {
    _jc_scm_scmsetCatchtable$sub_refs	scm_scmsetCatchtable;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmsetCatchtable$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmsetCatchtable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_scmsetCatchtable$sub_nonrefs	scm_scmsetCatchtable;
};

// Object instance structure
struct _jc_scm_scmsetCatchtable$object {
	_jc_scm_scmsetCatchtable$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmsetCatchtable$vtype	*vtype;
	_jc_scm_scmsetCatchtable$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmsetCatchtable$vtype _jc_scm_scmsetCatchtable$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmsetCatchtable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmsetCatchtable$class_object;

#endif	/* _JC_scm_scmsetCatchtable_H_ */

==> jc-1.4.6.tar.gz: scm/scmsetCatchtable.h <==
// class scm.scmsetCatchtable

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure
// @dep_class 4c297c365d1f0c22 scm_scmsetCatchtable

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_scmsetCatchtable_H_
#define _JC_scm_scmsetCatchtable_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_scmsetCatchtable$sub_refs	_jc_scm_scmsetCatchtable$sub_refs;
typedef struct _jc_scm_scmsetCatchtable$sub_nonrefs	_jc_scm_scmsetCatchtable$sub_nonrefs;
typedef struct _jc_scm_scmsetCatchtable$refs	_jc_scm_scmsetCatchtable$refs;
typedef struct _jc_scm_scmsetCatchtable$nonrefs	_jc_scm_scmsetCatchtable$nonrefs;
typedef struct _jc_scm_scmsetCatchtable$object	_jc_scm_scmsetCatchtable$object;

typedef const struct _jc_scm_scmsetCatchtable$vmethods	_jc_scm_scmsetCatchtable$vmethods;
typedef const struct _jc_scm_scmsetCatchtable$vtable	_jc_scm_scmsetCatchtable$vtable;
typedef const struct _jc_scm_scmsetCatchtable$vtype	_jc_scm_scmsetCatchtable$vtype;

// Constructors
extern void _jc_scm_scmsetCatchtable$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_scmsetCatchtable$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_scmsetCatchtable$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_scmsetCatchtable$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_scmsetCatchtable$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_scmsetCatchtable$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_scmsetCatchtable$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_scmsetCatchtable$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_scmsetCatchtable$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_scmsetCatchtable$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_scmsetCatchtable$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_scmsetCatchtable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_scmsetCatchtable$vmethods	scm_scmsetCatchtable;
};

// Vtype
struct _jc_scm_scmsetCatchtable$vtype {
	_jc_type			type;
	_jc_scm_scmsetCatchtable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmsetCatchtable$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmsetCatchtable$refs {
    _jc_scm_scmsetCatchtable$sub_refs	scm_scmsetCatchtable;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmsetCatchtable$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmsetCatchtable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_scmsetCatchtable$sub_nonrefs	scm_scmsetCatchtable;
};

// Object instance structure
struct _jc_scm_scmsetCatchtable$object {
	_jc_scm_scmsetCatchtable$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmsetCatchtable$vtype	*vtype;
	_jc_scm_scmsetCatchtable$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmsetCatchtable$vtype _jc_scm_scmsetCatchtable$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmsetCatchtable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmsetCatchtable$class_object;

#endif	/* _JC_scm_scmsetCatchtable_H_ */
